//! A test suite using PubChem to check that SMILES generated by this crate
//! can be used to resolve to actual compounds.

extern crate proteinogenic;
extern crate pubchem;

macro_rules! test_peptide {
    ($name:ident, $cid:expr, $($variant:ident),*) => {
        #[test]
        pub fn $name() {
            let s = proteinogenic::smiles([$(proteinogenic::AminoAcid::$variant),*]);
            let compound = pubchem::Compound::with_smiles(&s);
            let cid = compound.cids().expect("PubChem retrieval failed");
            assert_eq!(cid[0], $cid, "failed to retrieve compound using smiles {:?}", s);
        }
    };
}

test_peptide!(test_alanine, 5950, Ala);
test_peptide!(test_arginine, 6322, Arg);
test_peptide!(test_histidine, 6274, His);
test_peptide!(test_lysine, 5962, Lys);
test_peptide!(test_aspartate, 5960, Asp);
test_peptide!(test_glutamate, 33032, Glu);
test_peptide!(test_serine, 5951, Ser);
test_peptide!(test_threonine, 6288, Thr);
test_peptide!(test_asparagine, 6267, Asn);
test_peptide!(test_glutamine, 5961, Gln);
test_peptide!(test_glycine, 750, Gly);
test_peptide!(test_proline, 145742, Pro);
test_peptide!(test_cysteine, 5862, Cys);
test_peptide!(test_selenocystein, 6326983, Sec);
test_peptide!(test_valine, 6287, Val);
test_peptide!(test_isoleucine, 6306, Ile);
test_peptide!(test_leucine, 6106, Leu);
test_peptide!(test_methionine, 6137, Met);
test_peptide!(test_phenylalanine, 6140, Phe);
test_peptide!(test_tyrosine, 6057, Tyr);
test_peptide!(test_tryptophan, 6305, Trp);

test_peptide!(test_alanylvaline, 96799, Ala, Val);
test_peptide!(test_alanylhistidine, 9837455, Ala, His);
test_peptide!(test_prolylproline, 11622593, Pro, Pro);

test_peptide!(test_phenylalanylanalylvaline, 145457130, Phe, Ala, Val);
test_peptide!(test_threonylcysteinyltryptophan, 145458016, Thr, Cys, Trp);
